import aranet4
import datetime
import csv

# aranet4 mac address
device_mac = "XX:XX:XX:XX:XX:XX"

# Selection filter. Will export last 25 records
entry_filter = {
    "last": 25
}

# Fetch results
records = aranet4.client.get_all_records(
    device_mac,
    entry_filter,
    remove_empty=True # This will remove blank records, if range parameters (start,end,last) are specified
)

# write CSV file
with open('aranet_history.csv', 'w') as file:
    writer = csv.writer(file)

    header = [
        "date",
        "co2",
        "temperature",
        "humidity",
        "pressure"
    ]

    # Write CSV header
    writer.writerow(header)

    # Write CSV rows
    for line in records.value:
        row = [
            line.date.isoformat(),
            line.co2,
            line.temperature,
            line.humidity,
            line.pressure
        ]

        writer.writerow(row)



import aranet4
import requests
import time
import datetime
import sys
from influxdb import InfluxDBClient

def mkpt(device, key, value, timestr):
    return {
        "measurement": key,
        "tags": {
            "device": device,
        },
        "time": timestr,
        "fields": {
            "value": value
        }
    }

def readArg(argv, key, default, error="Invalid value"):
    if key in argv:
        idx = argv.index(key) + 1
        if idx >= len(argv):
            print(error)
            raise Exception(error)
        return argv[idx]
    return default

def main(argv):
    if len(argv) < 2:
        print("Missing device address and/or name.")
        return

    if "help" in argv or "?" in argv:
        print("Usage: python influx.py DEVICE_ADDRESS DEVICE_NAME [OPTIONS]")
        print("Options:")
        print("  -h          Fetch history")
        print("  -l <count>  Get <count> last records")
        print("")
        return

    hist = "-h" in argv

    limit = int(readArg(argv, "-l", 0, "Missing limit value"))

    device_mac = argv[0]
    device_name = argv[1]

    client = InfluxDBClient("127.0.0.1", "8086", "root", "root", "aranet4")
    client.create_database('aranet4')

    if hist:
        print("Fetching sensor history...")
        results = aranet4.client.get_all_records(mac_address=device_mac,
                                                 entry_filter={"last": limit})
    else:
        print("Fetching current readings...")
        current = aranet4.client.get_current_readings(mac_address=device_mac)

        now = datetime.datetime.now(datetime.timezone.utc).replace(microsecond=0)
        delta_ago = datetime.timedelta(seconds=current.ago)
        t = now - delta_ago
        t = t.replace(second=0)  # epoch, floored to minutes

        results = [{
            "time": t.timestamp(),
            "id": 0,
            "temperature": current.temperature,
            "pressure": current.pressure,
            "humidity": current.humidity,
            "co2": current.co2
        }]

    pts = []

    print("Sending history to InfluxDB...")
    for r in results:
        strtim = datetime.datetime.utcfromtimestamp(r["time"]).strftime('%Y-%m-%dT%H:%M:%SZ') # ISO 8601 UTC
        t = r["temperature"]
        p = r["pressure"]
        h = r["humidity"]
        c = r["co2"]
        i = r["id"]

        if (len(pts) > 2500): # flush
            client.write_points(pts)
            pts = []

        pts.append(mkpt(device_name, "temperature", t, strtim))
        pts.append(mkpt(device_name, "pressure",    p, strtim))
        pts.append(mkpt(device_name, "humidity",    h, strtim))
        pts.append(mkpt(device_name, "co2",         c, strtim))

    client.write_points(pts)


if __name__== "__main__":
  main(sys.argv[1:])



import sys
import aranet4

scanned_devices = {}

def on_scan(advertisement):
    if advertisement.device.address not in scanned_devices:
        print(f"Found new device:  {advertisement.device.name}")

    scanned_devices[advertisement.device.address] = advertisement

def print_advertisement(advertisement):
    print("=======================================")
    print(f"  Name:              {advertisement.device.name}")
    print(f"  Address:           {advertisement.device.address}")

    if advertisement.manufacturer_data:
        mf_data = advertisement.manufacturer_data
        print(f"  Version:           {mf_data.version}")
        print(f"  Integrations:      {mf_data.integrations}")
        # print(f"  Disconnected:      {mf_data.disconnected}")
        # print(f"  Calibration state: {mf_data.calibration_state.name}")
        # print(f"  DFU Active:        {mf_data.dfu_active:}")

    print(f"  RSSI:              {advertisement.device.rssi} dBm")

    if advertisement.readings:
        readings = advertisement.readings
        print("-------------------------------------")
        print(f"  CO2:           {readings.co2} pm")
        print(f"  Temperature:   {readings.temperature:.01f} \u00b0C")
        print(f"  Humidity:      {readings.humidity} %")
        print(f"  Pressure:      {readings.pressure:.01f} hPa")
        print(f"  Battery:       {readings.battery} &")
        print(f"  Status disp.:  {readings.status.name}")
        print(f"  Ago:           {readings.ago} s")
    print()


def main(argv):
    # Scan for 10 seconds, then print results
    print("Scanning Aranet4 devices...")
    aranet4.client.find_nearby(on_scan, 5)
    print(f"\nFound {len(scanned_devices)} devices:\n")

    for addr in scanned_devices:
        advertisement = scanned_devices[addr]
        print_advertisement(advertisement)


if __name__== "__main__":
    main(sys.argv[1:])



from dataclasses import asdict
import paho.mqtt.publish as publish
import aranet4
import sys

def buildMsgs(readings, topic):
    return [
        (topic + "temperature", readings["temperature"]),
        (topic + "pressure", readings["pressure"]),
        (topic + "humidity", readings["humidity"]),
        (topic + "co2", readings["co2"]),
        (topic + "battery", readings["battery"])
    ]

def readArg(argv, key, default, error="Invalid value"):
    if key in argv:
        idx = argv.index(key) + 1
        if idx >= len(argv):
            print(error)
            raise Exception(error)
        return argv[idx]
    return default

def main(argv):
    if len(argv) < 3:
        print("Missing device address, topic base and/or hostname.")
        argv[0] = "?"

    if "help" in argv or "?" in argv:
        print("Usage: python publish.py DEVICE_ADDRESS HOSTNAME TOPIC_BASE [OPTIONS]")
        print("  -P  <port>      Broker port")
        print("  -u  <user>      Auth user name")
        print("  -p  <password>  Auth user password")

        print("")
        return

    device_mac = argv[0]
    host = argv[1]
    topic = argv[2]

    port = readArg(argv, "-P", "1883")
    user = readArg(argv, "-u", "")
    pwd =  readArg(argv, "-p", "")

    auth = None
    
    if len(user) > 0:
        auth = {"username":user}
        if len(pwd) > 0: auth["password"] = pwd

    if (topic[-1] != "/"): topic += "/"

    current = aranet4.client.get_current_readings(device_mac)

    print("Publishing results...")
    publish.multiple(buildMsgs(asdict(current), topic), hostname=host, port=int(port), auth=auth)


if __name__== "__main__":
  main(sys.argv[1:])



import datetime
import io
import unittest
from unittest import mock

from aranet4 import client
from aranet4 import aranetctl
from aranet4.client import AranetType

result = client.CurrentReading(
    name="Aranet4 1234Z",
    version="v0.4.4",
    type=AranetType.ARANET4,
    temperature=21.75,
    humidity=48,
    pressure=1016.5,
    co2=933,
    battery=93,
    status=client.Status.GREEN,
    interval=300,
    ago=44,
    stored=2016
)


device_readings = """=======================================
  Name:     Aranet4 1234Z
  Logs:     2016
---------------------------------------
  CO2:            933 ppm
  Temperature:    21.8 °C
  Humidity:       48 %
  Pressure:       1016.5 hPa
  Battery:        93 %
  Status Display: GREEN
  Age:            44/300

"""

base_args = dict(
    device_mac="11:22:33:44:55:66",
    end=None,
    last=None,
    output=None,
    records=False,
    scan=False,
    set_btrange=None,
    set_integrations=None,
    set_interval=None,
    start=None,
    url=None,
    wait=False,
    co2=True,
    humi=True,
    pres=True,
    temp=True,
)


class DataManipulation(unittest.TestCase):
    def test_current_values(self):
        client.get_current_readings = mock.MagicMock(return_value=result)
        with unittest.mock.patch("sys.stdout", new=io.StringIO()) as fake_out:
            aranetctl.main(["C7:18:1E:21:F4:87"])
            self.assertEqual(device_readings, fake_out.getvalue())

    def test_parse_args1(self):
        expected = base_args.copy()
        args = aranetctl.parse_args(["11:22:33:44:55:66"])
        self.assertDictEqual(expected, args.__dict__)

    def test_parse_args2(self):
        expected = base_args.copy()
        expected["records"] = True
        args = aranetctl.parse_args("11:22:33:44:55:66 -r".split())
        self.assertDictEqual(expected, args.__dict__)

    def test_parse_args3(self):
        expected = base_args.copy()
        expected["records"] = True
        expected["l"] = 30
        args = aranetctl.parse_args("11:22:33:44:55:66 -r -l 30".split())
        self.assertDictEqual(expected, args.__dict__)

    def test_parse_args4(self):
        expected = base_args.copy()
        expected["records"] = True
        expected["start"] = datetime.datetime(2022, 2, 14, 15, 16)
        expected["end"] = datetime.datetime(2022, 2, 17, 18, 19)
        args = aranetctl.parse_args(
            "11:22:33:44:55:66 -r -s 2022-02-14T15:16 -e 2022-02-17T18:19".split()
        )
        self.assertDictEqual(expected, args.__dict__)

    def test_parse_args3(self):
        expected = base_args.copy()
        expected["records"] = True
        expected["temp"] = False
        args = aranetctl.parse_args("11:22:33:44:55:66 -r --xt".split())
        self.assertDictEqual(expected, args.__dict__)

    def test_calc_log_last_n(self):
        mock_points = [datetime.datetime.now(datetime.timezone.utc)] * 200
        start, end = client._calc_start_end(mock_points, {'last': 20})
        # Requested numbers are inclusive so difference is 19 although
        # 20 data points have been requested
        self.assertEqual(181, start)
        self.assertEqual(200, end)
        self.assertEqual(19, end - start)

    def test_log_times_1(self):
        log_records = 13
        log_interval = 300
        expected = []
        expected_start = datetime.datetime(2000, 10, 11, 22, 59, 10)
        for idx in range(log_records):
            expected.append(
                expected_start + datetime.timedelta(seconds=log_interval * idx)
            )

        now = datetime.datetime(2000, 10, 11, 23, 59, 30)
        times = client._log_times(now, log_records, log_interval, 20)
        self.assertListEqual(expected, times)


if __name__ == "__main__":
    unittest.main()



import datetime
import io
import unittest
from unittest import mock

from aranet4 import client
from aranet4.client import Aranet4Advertisement
from aranet4.client import AranetType

from bleak.backends.scanner import AdvertisementData
from bleak import BleakClient

def fake_ad_data(name, service_uuid, manufacturer_data, address="00:11:22:33:44:55"):
    """Return a BluetoothServiceInfoBleak for use in testing."""

    ad_data = AdvertisementData(
        local_name=name,
        manufacturer_data=manufacturer_data,
        service_data={},
        service_uuids=[service_uuid],
        rssi=-60,
        tx_power=-127,
        platform_data=(),
    )

    device = BleakClient(address)
    device.name = name

    return {
        "ad_data": ad_data,
        "device": device
    }

TEST_DATA_ARANET_4 = {
    "name": "Aranet4 12345",
    "uuid": "f0cd1400-95da-4f4b-9ac8-aa55d312af0c",
    "manufacturer_data": {1794: b"!\x05\x03\x01\x00\x05\x00\x01C\x04\x9f\x01\x8b\'5\x0c\x02<\x00\x10\x00U"},
    "manufacturer_data_short": {1794: b"!\x05\x03\x01\x00\x05\x00\x01C\x04\x9f\x01\x8b\'5\x0c\x02<\x00\x10"},
    "manufacturer_data_old_fw": {1794: b"\x21\x0a\x04\x00\x00\x00\x00"},
    "manufacturer_data_no_integrations": {1794: b"\x01\x00\x02\x01\x00\x00\x00"},
    "manufacturer_data_bad": {1794: b"\x01\x00\x02"},
}

TEST_DATA_ARANET_2 = {
    "name": "Aranet2 278F8",
    "uuid": "f0cd1400-95da-4f4b-9ac8-aa55d312af0c",
    "manufacturer_data": {1794: b"\x01!\x04\x04\x01\x00\x00\x00\x00\x00\x99\x01\x00\x00\n\x02\x00;\x00x\x00R\x00d"},
    "manufacturer_data_no_integrations": {1794: b"\x01\x01\x04\x04\x01\x00\x00\x00\x00\x00\x99\x01\x00\x00\n\x02\x00;\x00x\x00R\x00d"},
}

TEST_DATA_ARANET_RADIATION = {
    "name": "Aranet\u2622 27DB3",
    "uuid": "f0cd1400-95da-4f4b-9ac8-aa55d312af0c",
    "manufacturer_data": {1794: b"\x02!&\x04\x01\x00\xd03\x00\x00l`\x06\x00\x82\x00\x00c\x00,\x01X\x00r"},
    "manufacturer_data_no_integrations": {1794: b"\x02\x01&\x04\x01\x00\xd03\x00\x00l`\x06\x00\x82\x00\x00c\x00,\x01X\x00r"},
}

TEST_DATA_ARANET_RADON = {
    "name": "AranetRn 298C9",
    "uuid": "f0cd1400-95da-4f4b-9ac8-aa55d312af0c",
    "manufacturer_data": {1794: b"\x03!\x04\x06\x01\x00\x00\x00\x07\x00\xfe\x01\xc9\'\xce\x01\x00d\x01X\x02\xf6\x01\x08"},
}


class DataManipulation(unittest.TestCase):
    # ---------------------------------------------
    #  Test data validation helpers
    # ---------------------------------------------

    def _test_aranet_4(self, data):
        ad = Aranet4Advertisement(data["device"], data["ad_data"])

        self.assertTrue(ad.manufacturer_data.integrations)
        self.assertEqual("v1.3.5", str(ad.manufacturer_data.version))

        self.assertEqual(AranetType.ARANET4, ad.readings.type)
        self.assertEqual(1091, ad.readings.co2)
        self.assertEqual(20.8, ad.readings.temperature)
        self.assertEqual(53, ad.readings.humidity)
        self.assertEqual(1012.3, ad.readings.pressure)
        self.assertEqual(12, ad.readings.battery)
        self.assertEqual(16, ad.readings.ago)
        self.assertEqual(60, ad.readings.interval)

    def _test_aranet_2(self, data):
        ad = Aranet4Advertisement(data["device"], data["ad_data"])

        self.assertTrue(ad.manufacturer_data.integrations)
        self.assertEqual("v1.4.4", str(ad.manufacturer_data.version))

        self.assertEqual(AranetType.ARANET2, ad.readings.type)
        self.assertEqual(20.5, ad.readings.temperature)
        self.assertEqual(52.2, ad.readings.humidity)
        self.assertEqual(59, ad.readings.battery)
        self.assertEqual(82, ad.readings.ago)
        self.assertEqual(120, ad.readings.interval)

    def _test_aranet_radiation(self, data):
        ad = Aranet4Advertisement(data["device"], data["ad_data"])

        self.assertTrue(ad.manufacturer_data.integrations)
        self.assertEqual("v1.4.38", str(ad.manufacturer_data.version))

        self.assertEqual(AranetType.ARANET_RADIATION, ad.readings.type)
        self.assertEqual(130, ad.readings.radiation_rate)
        self.assertEqual(13264, ad.readings.radiation_total)
        self.assertEqual(417900, ad.readings.radiation_duration)
        self.assertEqual(99, ad.readings.battery)
        self.assertEqual(88, ad.readings.ago)
        self.assertEqual(300, ad.readings.interval)

    def _test_aranet_radon(self, data):
        ad = Aranet4Advertisement(data["device"], data["ad_data"])

        self.assertTrue(ad.manufacturer_data.integrations)
        self.assertEqual("v1.6.4", str(ad.manufacturer_data.version))

        self.assertEqual(AranetType.ARANET_RADON, ad.readings.type)
        self.assertEqual(25.5, ad.readings.temperature)
        self.assertEqual(46.2, ad.readings.humidity)
        self.assertEqual(1018.5, ad.readings.pressure)
        self.assertEqual(7, ad.readings.radon_concentration)
        self.assertEqual(100, ad.readings.battery)
        self.assertEqual(502, ad.readings.ago)
        self.assertEqual(600, ad.readings.interval)
    # ---------------------------------------------
    #  Test variations
    # ---------------------------------------------

    def test_aranet_4(self):
        srcdata = TEST_DATA_ARANET_4
        self._test_aranet_4(fake_ad_data(
            srcdata["name"],
            srcdata["uuid"],
            srcdata["manufacturer_data"],
        ))

    def test_aranet_4_noname(self):
        srcdata = TEST_DATA_ARANET_4
        self._test_aranet_4(fake_ad_data(
            None,
            srcdata["uuid"],
            srcdata["manufacturer_data"],
        ))

    def test_aranet_4_invalid(self):
        data_old = fake_ad_data(
            TEST_DATA_ARANET_4["name"],
            TEST_DATA_ARANET_4["uuid"],
            TEST_DATA_ARANET_4["manufacturer_data_old_fw"],
        )

        data_no_integrations = fake_ad_data(
            TEST_DATA_ARANET_4["name"],
            TEST_DATA_ARANET_4["uuid"],
            TEST_DATA_ARANET_4["manufacturer_data_no_integrations"],
        )

        data_short = fake_ad_data(
            TEST_DATA_ARANET_4["name"],
            TEST_DATA_ARANET_4["uuid"],
            TEST_DATA_ARANET_4["manufacturer_data_short"],
        )

        data_bad = fake_ad_data(
            TEST_DATA_ARANET_4["name"],
            TEST_DATA_ARANET_4["uuid"],
            TEST_DATA_ARANET_4["manufacturer_data_bad"],
        )

        ad_old = Aranet4Advertisement(data_old["device"], data_old["ad_data"])
        self.assertFalse(ad_old.manufacturer_data.integrations)
        self.assertEqual("v0.4.10", str(ad_old.manufacturer_data.version))
        self.assertFalse(ad_old.readings)

        ad_no_integrations = Aranet4Advertisement(data_no_integrations["device"], data_no_integrations["ad_data"])
        self.assertFalse(ad_no_integrations.manufacturer_data.integrations)
        self.assertEqual("v1.2.0", str(ad_no_integrations.manufacturer_data.version))
        self.assertFalse(ad_no_integrations.readings)

        ad_short = Aranet4Advertisement(data_short["device"], data_short["ad_data"])
        self.assertFalse(ad_short.manufacturer_data.integrations)
        self.assertEqual("v1.3.5", str(ad_short.manufacturer_data.version))
        self.assertFalse(ad_short.readings)

        ad_bad = Aranet4Advertisement(data_bad["device"], data_bad["ad_data"])
        self.assertFalse(ad_bad.manufacturer_data)

    def test_aranet_2_invalid(self):
        data_no_integrations = fake_ad_data(
            TEST_DATA_ARANET_2["name"],
            TEST_DATA_ARANET_2["uuid"],
            TEST_DATA_ARANET_2["manufacturer_data_no_integrations"],
        )

        ad_no_integrations = Aranet4Advertisement(data_no_integrations["device"], data_no_integrations["ad_data"])
        self.assertFalse(ad_no_integrations.manufacturer_data.integrations)
        self.assertEqual("v1.4.4", str(ad_no_integrations.manufacturer_data.version))
        self.assertFalse(ad_no_integrations.readings)

    def test_aranet_radiation_invalid(self):
        data_no_integrations = fake_ad_data(
            TEST_DATA_ARANET_RADIATION["name"],
            TEST_DATA_ARANET_RADIATION["uuid"],
            TEST_DATA_ARANET_RADIATION["manufacturer_data_no_integrations"],
        )

        ad_no_integrations = Aranet4Advertisement(data_no_integrations["device"], data_no_integrations["ad_data"])
        self.assertFalse(ad_no_integrations.manufacturer_data.integrations)
        self.assertEqual("v1.4.38", str(ad_no_integrations.manufacturer_data.version))
        self.assertFalse(ad_no_integrations.readings)

    def test_aranet_2(self):
        srcdata = TEST_DATA_ARANET_2
        self._test_aranet_2(fake_ad_data(
            srcdata["name"],
            srcdata["uuid"],
            srcdata["manufacturer_data"],
        ))

    def test_aranet_2_noname(self):
        srcdata = TEST_DATA_ARANET_2
        self._test_aranet_2(fake_ad_data(
            srcdata["name"],
            srcdata["uuid"],
            srcdata["manufacturer_data"],
        ))

    def test_aranet_radiation(self):
        srcdata = TEST_DATA_ARANET_RADIATION
        self._test_aranet_radiation(fake_ad_data(
            srcdata["name"],
            srcdata["uuid"],
            srcdata["manufacturer_data"],
        ))

    def test_aranet_radiation_noname(self):
        srcdata = TEST_DATA_ARANET_RADIATION
        self._test_aranet_radiation(fake_ad_data(
            None,
            srcdata["uuid"],
            srcdata["manufacturer_data"],
        ))

    def test_aranet_radon(self):
        srcdata = TEST_DATA_ARANET_RADON
        self._test_aranet_radon(fake_ad_data(
            srcdata["name"],
            srcdata["uuid"],
            srcdata["manufacturer_data"],
        ))

    def test_aranet_radon_noname(self):
        srcdata = TEST_DATA_ARANET_RADON
        self._test_aranet_radon(fake_ad_data(
            None,
            srcdata["uuid"],
            srcdata["manufacturer_data"],
        ))

if __name__ == "__main__":
    unittest.main()



import aranet4
import requests
import time
import datetime
import sys
from influxdb import InfluxDBClient

def mkpt(device, key, value, timestr):
    return {
        "measurement": key,
        "tags": {
            "device": device,
        },
        "time": timestr,
        "fields": {
            "value": value
        }
    }

def main(argv):
    if len(argv) < 2:
        print("Missing file name and device name")
        return

    if "help" in argv or "?" in argv:
        print("Usage: python import.py DEVICE_ADDRESS DEVICE_NAME")
        print("")
        return

    results = []

    device_name = argv[1]
    with open(argv[0]) as f:
        lines = f.readlines()

    for ln in lines:
        pt = ln.strip().split(";")
        if (len(pt) < 5):
            continue

        id = pt[0]
        timestr = pt[1] + ":00"
        dt = datetime.datetime.strptime(timestr, '%Y-%m-%d %H:%M:%S')
        dt = dt - datetime.timedelta(hours=1)

        t = float(pt[2])
        h = int(pt[3])
        p = float(pt[4])
        c = int(pt[5])

        res = {
            "id": id,
            "time": dt.strftime('%Y-%m-%dT%H:%M:%SZ'),
            "temperature": t,
            "pressure": p,
            "humidity": h,
            "co2": c
        }

        results.append(res)

    client = InfluxDBClient("127.0.0.1", "8086", "root", "root", "aranet4")
    client.create_database('aranet4')

    print("Sending history to InfluxDB...")
    pts = []

    for r in results:
        strtim = r["time"]
        t = r["temperature"]
        p = r["pressure"]
        h = r["humidity"]
        c = r["co2"]
        i = r["id"]

        if (len(pts) > 10000): # flush
            client.write_points(pts)
            pts = []

        pts.append(mkpt(device_name, "temperature", t, strtim))
        pts.append(mkpt(device_name, "pressure",    p, strtim))
        pts.append(mkpt(device_name, "humidity",    h, strtim))
        pts.append(mkpt(device_name, "co2",         c, strtim))

    client.write_points(pts)

if __name__== "__main__":
  main(sys.argv[1:])



import sys
from aranet4 import Aranet4Scanner
import asyncio
import time

"""
    Custom scanner setup example.
    This will run scanner forever (or until interupted by Ctrl^C)
"""

def on_scan(advertisement):
    if not advertisement.readings:
        return

    print("=======================================")
    print(f"  Name:     {advertisement.device.name}")
    print(f"  Address:  {advertisement.device.address}")

    if advertisement.manufacturer_data:
        mf_data = advertisement.manufacturer_data
        print(f"  Version:           {mf_data.version}")
        print(f"  Integrations:      {mf_data.integrations}")
        # print(f"  Disconnected:      {mf_data.disconnected}")
        # print(f"  Calibration state: {mf_data.calibration_state.name}")
        # print(f"  DFU Active:        {mf_data.dfu_active:}")

    print(f"  RSSI:              {advertisement.device.rssi} dBm")

    if advertisement.readings:
        print("--------------------------------------")
        print(f"  CO2:           {advertisement.readings.co2} pm")
        print(f"  Temperature:   {advertisement.readings.temperature:.01f} \u00b0C")
        print(f"  Humidity:      {advertisement.readings.humidity} %")
        print(f"  Pressure:      {advertisement.readings.pressure:.01f} hPa")
        print(f"  Battery:       {advertisement.readings.battery} &")
        print(f"  Status disp.:  {advertisement.readings.status.name}")
        print(f"  Ago:           {advertisement.readings.ago} s")
    print()

async def main(argv):
    scanner = Aranet4Scanner(on_scan)
    await scanner.start()
    while (True): # Run forever
        await asyncio.sleep(1)
    await scanner.stop()

    
if __name__== "__main__":
    try:
        asyncio.run(main(sys.argv[1:]))
    except KeyboardInterrupt:
        print("User interupted.")



import csv
import difflib
from pathlib import Path
import tempfile
import unittest

from aranet4 import client
from aranet4 import aranetctl

here = Path(__file__).parent
data_file = here.joinpath("data", "aranet4_readings.csv")


def build_data():
    log_filter = client.Filter(1, 14, True, True, True, True, True, True, True, True)
    records = client.Record("mock_device", "v1234", 14, log_filter)
    with open(data_file, mode="r") as csvfile:
        reader = csv.DictReader(csvfile)
        for row in reader:
            records.value.append(client.RecordItem(**row))
    return records


class CSVCreation(unittest.TestCase):
    def setUp(self):
        # Create data object
        self.records = build_data()
        # Create a temporary directory
        self.test_file = tempfile.NamedTemporaryFile(delete=True)

    def tearDown(self):
        self.test_file.close()

    def test_simple_write(self):
        aranetctl.write_csv(self.test_file.name, self.records)
        ref = data_file.read_text().splitlines(keepends=False)
        new = Path(self.test_file.name).read_text().splitlines(keepends=False)
        cmp_result = list(
            difflib.context_diff(ref, new, fromfile="reference", tofile="test output")
        )
        self.assertListEqual([], cmp_result)


if __name__ == "__main__":
    unittest.main()
